WifiPhyRate

Enum WifiPhyRate 

#[repr(u32)]
pub enum WifiPhyRate {
Show 34 variants Rate1mL = 0, Rate2m = 1, Rate5mL = 2, Rate11mL = 3, Rate2mS = 4, Rate5mS = 5, Rate11mS = 6, Rate48m = 7, Rate24m = 8, Rate12m = 9, Rate6m = 10, Rate54m = 11, Rate36m = 12, Rate18m = 13, Rate9m = 14, RateMcs0Lgi = 15, RateMcs1Lgi = 16, RateMcs2Lgi = 17, RateMcs3Lgi = 18, RateMcs4Lgi = 19, RateMcs5Lgi = 20, RateMcs6Lgi = 21, RateMcs7Lgi = 22, RateMcs0Sgi = 23, RateMcs1Sgi = 24, RateMcs2Sgi = 25, RateMcs3Sgi = 26, RateMcs4Sgi = 27, RateMcs5Sgi = 28, RateMcs6Sgi = 29, RateMcs7Sgi = 30, RateLora250k = 31, RateLora500k = 32, RateMax = 33,
}
Available on crate features esp-now and unstable only.
ESP-NOW rate of specified interface.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Rate1mL = 0

< 1 Mbps with long preamble



Rate2m = 1

< 2 Mbps with long preamble



Rate5mL = 2

< 5.5 Mbps with long preamble



Rate11mL = 3

< 11 Mbps with long preamble



Rate2mS = 4

< 2 Mbps with short preamble



Rate5mS = 5

< 5.5 Mbps with short preamble



Rate11mS = 6

< 11 Mbps with short preamble



Rate48m = 7

< 48 Mbps



Rate24m = 8

< 24 Mbps



Rate12m = 9

< 12 Mbps



Rate6m = 10

< 6 Mbps



Rate54m = 11

< 54 Mbps



Rate36m = 12

< 36 Mbps



Rate18m = 13

< 18 Mbps



Rate9m = 14

< 9 Mbps



RateMcs0Lgi = 15

< MCS0 with long GI, 6.5 Mbps for 20MHz, 13.5 Mbps for 40MHz



RateMcs1Lgi = 16

< MCS1 with long GI, 13 Mbps for 20MHz, 27 Mbps for 40MHz



RateMcs2Lgi = 17

< MCS2 with long GI, 19.5 Mbps for 20MHz, 40.5 Mbps for 40MHz



RateMcs3Lgi = 18

< MCS3 with long GI, 26 Mbps for 20MHz, 54 Mbps for 40MHz



RateMcs4Lgi = 19

< MCS4 with long GI, 39 Mbps for 20MHz, 81 Mbps for 40MHz



RateMcs5Lgi = 20

< MCS5 with long GI, 52 Mbps for 20MHz, 108 Mbps for 40MHz



RateMcs6Lgi = 21

< MCS6 with long GI, 58.5 Mbps for 20MHz, 121.5 Mbps for 40MHz



RateMcs7Lgi = 22

< MCS7 with long GI, 65 Mbps for 20MHz, 135 Mbps for 40MHz



RateMcs0Sgi = 23

< MCS0 with short GI, 7.2 Mbps for 20MHz, 15 Mbps for 40MHz



RateMcs1Sgi = 24

< MCS1 with short GI, 14.4 Mbps for 20MHz, 30 Mbps for 40MHz



RateMcs2Sgi = 25

< MCS2 with short GI, 21.7 Mbps for 20MHz, 45 Mbps for 40MHz



RateMcs3Sgi = 26

< MCS3 with short GI, 28.9 Mbps for 20MHz, 60 Mbps for 40MHz



RateMcs4Sgi = 27

< MCS4 with short GI, 43.3 Mbps for 20MHz, 90 Mbps for 40MHz



RateMcs5Sgi = 28

< MCS5 with short GI, 57.8 Mbps for 20MHz, 120 Mbps for 40MHz



RateMcs6Sgi = 29

< MCS6 with short GI, 65 Mbps for 20MHz, 135 Mbps for 40MHz



RateMcs7Sgi = 30

< MCS7 with short GI, 72.2 Mbps for 20MHz, 150 Mbps for 40MHz



RateLora250k = 31

< 250 Kbps



RateLora500k = 32

< 500 Kbps



RateMax = 33

Max