pub struct ReceiveInfo {
pub src_address: [u8; 6],
pub dst_address: [u8; 6],
pub rx_control: RxControlInfo,
}Available on crate features
esp-now and unstable only.Expand description
Information about a received packet.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields
src_address: [u8; 6]The source address of the received packet.
dst_address: [u8; 6]The destination address of the received packet.
rx_control: RxControlInfoRx control info of ESP-NOW packet.